"""
Contain class Label, which represents a UI element
displaying static text.
"""

import pygame

class Label:
    """
    UI element displaying static text with transparent background.
        
    @ivar text: the text
    @type text: string
    @ivar font: the text's font
    @type font: C{pygame.font.Font}
    @ivar position: (x,y) coordinate of the 
        top-left corner of the text
    @type position: 2-tuple of integers
    @ivar color: the text's foreground color
    @type color: 3-tuple of integers
    @ivar surface: Pygame surface containing
        the text
    @type surface: C{pygame.Surface}
    """
    def __init__(self, text, font, position=(0,0), color=(255,255,255)):
        """
        Create a label with the given parameters.
        """
        self.text = text
        self.font = font
        self.position = position
        self.color = color
        self.surface = None
        self.update()
    
    def update(self):
        """
        Recreate the surface containing the text.
        """
        self.surface = self.font.render(self.text, True, self.color)
    
    def blit_to(self, surface):
        """
        Blit the surface containing the text to the
        given surface.
        """
        surface.blit(self.surface, self.position)
    
    def set_text(self, text):
        """
        Set the label's text.
        """
        self.text = text
        self.update()
        
    def set_font(self, font):
        """
        Set the label's font.
        """
        self.font = font
        self.update()
        
    def set_position(self, position):
        """
        Set the label's (x,y) position.
        """
        self.position = position
    
    def set_color(self, color):
        """
        Set the label's color.
        """
        self.color = color
        self.update()