"""
Contain the abstract class Mode, representing game modes.
"""

class Mode:
    """
    Abstract class representing game modes.
    
    @ivar engine: the game engine
    @type engine: C{engine.Engine}    
    """
    def __init__(self, engine):
        """
        Create a game mode.
        
        @param engine: the game engine
        @type engine: C{engine.Engine}
        """
        self.engine = engine
        
    def handle(self, event):
        """
        Handle a Pygame event. The default behavior is 
        to call the engine's C{handle} method.
        """
        self.engine.handle(event)
    
    def render(self, surface):
        """
        Render the game graphics to the given Pygame surface.
        Called once per frame.
        """
        pass
    
    def preprocess(self):
        """
        Initialize the mode's internal states
        before handling input. Called once per frame.
        """
        pass
    
    def process(self):
        """
        Update the mode's internal states.
        Call once per frame.
        """
        pass
    
    def switched_into(self, from_mode):
        """
        Initialize the mode's internal states
        after the engine switches from C{from_mode}
        to the mode represented by the class.
        
        @param from_mode: the mode the engine comes from
        @type from_mode: C{mode.Mode}
        """
        pass